==> symphonia-format-isomp4-0.3.0.crate: symphonia-format-isomp4-0.3.0/src/atoms/mvex.rs <==
// Symphonia
// Copyright (c) 2020 The Project Symphonia Developers.
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at https://mozilla.org/MPL/2.0/.

use symphonia_core::errors::Result;
use symphonia_core::io::ByteStream;

use crate::atoms::{Atom, AtomHeader, AtomIterator, AtomType, MehdAtom, TrexAtom};

/// Movie extends atom.
#[derive(Debug)]
pub struct MvexAtom {
    /// Atom header.
    pub header: AtomHeader,
    /// Movie extends header, optional.
    pub mehd: Option<MehdAtom>,
    /// Track extends box, one per track.
    pub trexs: Vec<TrexAtom>,
}

impl Atom for MvexAtom {
    fn header(&self) -> AtomHeader {
        self.header
    }

    fn read<B: ByteStream>(reader: &mut B, header: AtomHeader) -> Result<Self> {
        let mut iter = AtomIterator::new(reader, header);

        let mut mehd = None;
        let mut trexs = Vec::new();

        while let Some(header) = iter.next()? {
            match header.atype {
                AtomType::MovieExtendsHeader => {
                    mehd = Some(iter.read_atom::<MehdAtom>()?);
                }
                AtomType::TrackExtends => {
                    let trex = iter.read_atom::<TrexAtom>()?;
                    trexs.push(trex);
                }
                _ => ()
            }
        }

        Ok(MvexAtom {
            header,
            mehd,
            trexs,
        })
    }

}

==> symphonia-format-isomp4-0.4.0.crate: symphonia-format-isomp4-0.4.0/src/atoms/mvex.rs <==
// Symphonia
// Copyright (c) 2019-2021 The Project Symphonia Developers.
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at https://mozilla.org/MPL/2.0/.

use symphonia_core::errors::Result;
use symphonia_core::io::ReadBytes;

use crate::atoms::{Atom, AtomHeader, AtomIterator, AtomType, MehdAtom, TrexAtom};

/// Movie extends atom.
#[derive(Debug)]
pub struct MvexAtom {
    /// Atom header.
    pub header: AtomHeader,
    /// Movie extends header, optional.
    pub mehd: Option<MehdAtom>,
    /// Track extends box, one per track.
    pub trexs: Vec<TrexAtom>,
}

impl Atom for MvexAtom {
    fn header(&self) -> AtomHeader {
        self.header
    }

    fn read<B: ReadBytes>(reader: &mut B, header: AtomHeader) -> Result<Self> {
        let mut iter = AtomIterator::new(reader, header);

        let mut mehd = None;
        let mut trexs = Vec::new();

        while let Some(header) = iter.next()? {
            match header.atype {
                AtomType::MovieExtendsHeader => {
                    mehd = Some(iter.read_atom::<MehdAtom>()?);
                }
                AtomType::TrackExtends => {
                    let trex = iter.read_atom::<TrexAtom>()?;
                    trexs.push(trex);
                }
                _ => ()
            }
        }

        Ok(MvexAtom {
            header,
            mehd,
            trexs,
        })
    }

}
